@@ -24,23 +24,25 @@
 #include <ctime>
 #include <unistd.h>
 
-#include <QDir>
 #include <QCommandLineParser>
+#include <QDir>
 #include <QRandomGenerator>
 
-#include <version.h>
-#include <util/error.h>
-#include <util/functions.h>
-#include <peer/authenticationmonitor.h>
 #include <interfaces/serverinterface.h>
+#include <peer/authenticationmonitor.h>
 #include <peer/utpex.h>
-#include <util/waitjob.h>
+#include <util/error.h>
 #include <util/fileops.h>
-
+#include <util/functions.h>
+#include <util/waitjob.h>
+#include <version.h>
 
 using namespace bt;
 
-KTCLI::KTCLI(int argc, char** argv) : QCoreApplication(argc, argv), tc(new TorrentControl()), updates(0)
+KTCLI::KTCLI(int argc, char **argv)
+    : QCoreApplication(argc, argv)
+    , tc(new TorrentControl())
+    , updates(0)
 {
     parser.addPositionalArgument("url", tr("Torrent to open"));
     parser.addOption(QCommandLineOption("port", tr("Port to use"), "<port>", "6881"));
@@ -52,8 +54,8 @@ KTCLI::KTCLI(int argc, char** argv) : QCoreApplication(argc, argv), tc(new Torre
 
     bt::SetClientInfo("ktcli", bt::MAJOR, bt::MINOR, bt::RELEASE, bt::NORMAL, "KT");
     bt::InitLog("ktcli.log", false, true, false);
-    connect(tc.get(), SIGNAL(finished(bt::TorrentInterface*)), this, SLOT(finished(bt::TorrentInterface*)));
-    connect(this, SIGNAL(aboutToQuit()), this, SLOT(shutdown()));
+    connect(tc.get(), &TorrentInterface::finished, this, &KTCLI::finished);
+    connect(this, &QCoreApplication::aboutToQuit, this, &KTCLI::shutdown);
 }
 
 KTCLI::~KTCLI()
@@ -94,11 +96,11 @@ bool KTCLI::start()
         }
     }
 
-    if (parser.positionalArguments().isEmpty()) return false;
+    if (parser.positionalArguments().isEmpty())
+        return false;
     return load(QUrl::fromLocalFile(parser.positionalArguments().at(0)));
 }
 
-
 bool KTCLI::load(const QUrl &url)
 {
     QDir dir(url.toLocalFile());
@@ -106,7 +108,7 @@ bool KTCLI::load(const QUrl &url)
         // Load existing torrent
         if (loadFromDir(dir.absolutePath())) {
             tc->start();
-            connect(&timer, SIGNAL(timeout()), this, SLOT(update()));
+            connect(&timer, &QTimer::timeout, this, &KTCLI::update);
             timer.start(250);
             return true;
         }
@@ -114,7 +116,7 @@ bool KTCLI::load(const QUrl &url)
         QString path = url.toLocalFile();
         if (loadFromFile(path)) {
             tc->start();
-            connect(&timer, SIGNAL(timeout()), this, SLOT(update()));
+            connect(&timer, &QTimer::timeout, this, &KTCLI::update);
             timer.start(250);
             return true;
         }
@@ -140,58 +142,56 @@ QString KTCLI::tempDir()
     return tmpdir.absolutePath();
 }
 
-bool KTCLI::loadFromFile(const QString & path)
+bool KTCLI::loadFromFile(const QString &path)
 {
     try {
         tc->init(this, bt::LoadFile(path), tempDir(), QDir::currentPath());
         tc->setLoadUrl(QUrl(path));
         tc->createFiles();
         return true;
-    } catch (bt::Error & err) {
+    } catch (bt::Error &err) {
         Out(SYS_GEN | LOG_IMPORTANT) << err.toString() << endl;
         return false;
     }
 }
 
-bool KTCLI::loadFromDir(const QString& path)
+bool KTCLI::loadFromDir(const QString &path)
 {
     try {
         tc->init(this, bt::LoadFile(path + "/torrent"), path, QString());
         tc->createFiles();
         return true;
-    } catch (bt::Error & err) {
+    } catch (bt::Error &err) {
         Out(SYS_GEN | LOG_IMPORTANT) << err.toString() << endl;
         return false;
     }
 }
 
-
-bool KTCLI::notify(QObject* obj, QEvent* ev)
+bool KTCLI::notify(QObject *obj, QEvent *ev)
 {
     try {
         return QCoreApplication::notify(obj, ev);
-    } catch (bt::Error & err) {
+    } catch (bt::Error &err) {
         Out(SYS_GEN | LOG_DEBUG) << "Error: " << err.toString() << endl;
-    } catch (std::exception & err) {
+    } catch (std::exception &err) {
         Out(SYS_GEN | LOG_DEBUG) << "Error: " << err.what() << endl;
     }
 
     return true;
 }
 
-bool KTCLI::alreadyLoaded(const bt::SHA1Hash& ih) const
+bool KTCLI::alreadyLoaded(const bt::SHA1Hash &ih) const
 {
     Q_UNUSED(ih);
     return false;
 }
 
-void KTCLI::mergeAnnounceList(const bt::SHA1Hash& ih, const bt::TrackerTier* trk)
+void KTCLI::mergeAnnounceList(const bt::SHA1Hash &ih, const bt::TrackerTier *trk)
 {
     Q_UNUSED(ih);
     Q_UNUSED(trk);
 }
 
-
 void KTCLI::update()
 {
     bt::UpdateCurrentTime();
@@ -204,18 +204,18 @@ void KTCLI::update()
     }
 }
 
-void KTCLI::finished(bt::TorrentInterface* tor)
+void KTCLI::finished(bt::TorrentInterface *tor)
 {
     Q_UNUSED(tor);
     Out(SYS_GEN | LOG_NOTICE) << "Torrent fully downloaded" << endl;
-    QTimer::singleShot(0, this, SLOT(shutdown()));
+    QTimer::singleShot(0, this, &KTCLI::shutdown);
 }
 
 void KTCLI::shutdown()
 {
     AuthenticationMonitor::instance().shutdown();
 
-    WaitJob* j = new WaitJob(2000);
+    WaitJob *j = new WaitJob(2000);
     tc->stop(j);
     if (j->needToWait())
         j->exec();
@@ -225,4 +225,3 @@ void KTCLI::shutdown()
     Globals::instance().shutdownUTPServer();
     quit();
 }
-
