@@ -22,29 +22,33 @@
 
 namespace bt
 {
-
-QString SOAP::createCommand(const QString & action, const QString & service)
+QString SOAP::createCommand(const QString &action, const QString &service)
 {
-    QString comm = QString("<?xml version=\"1.0\"?>"
-                           "<SOAP-ENV:Envelope xmlns:SOAP-ENV=\"http://schemas.xmlsoap.org/soap/envelope/\" "
-                           "SOAP-ENV:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"
-                           "<SOAP-ENV:Body>"
-                           "<m:%1 xmlns:m=\"%2\"/>"
-                           "</SOAP-ENV:Body></SOAP-ENV:Envelope>")
-                   .arg(action).arg(service);
+    QString comm = QString(
+                       "<?xml version=\"1.0\"?>"
+                       "<SOAP-ENV:Envelope xmlns:SOAP-ENV=\"http://schemas.xmlsoap.org/soap/envelope/\" "
+                       "SOAP-ENV:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"
+                       "<SOAP-ENV:Body>"
+                       "<m:%1 xmlns:m=\"%2\"/>"
+                       "</SOAP-ENV:Body></SOAP-ENV:Envelope>")
+                       .arg(action)
+                       .arg(service);
 
     return comm;
 }
 
-QString SOAP::createCommand(const QString & action, const QString & service, const QList<Arg> & args)
+QString SOAP::createCommand(const QString &action, const QString &service, const QList<Arg> &args)
 {
-    QString comm = QString("<?xml version=\"1.0\"?>"
-                           "<SOAP-ENV:Envelope xmlns:SOAP-ENV=\"http://schemas.xmlsoap.org/soap/envelope/\" "
-                           "SOAP-ENV:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"
-                           "<SOAP-ENV:Body>"
-                           "<m:%1 xmlns:m=\"%2\">").arg(action).arg(service);
+    QString comm = QString(
+                       "<?xml version=\"1.0\"?>"
+                       "<SOAP-ENV:Envelope xmlns:SOAP-ENV=\"http://schemas.xmlsoap.org/soap/envelope/\" "
+                       "SOAP-ENV:encodingStyle=\"http://schemas.xmlsoap.org/soap/encoding/\">"
+                       "<SOAP-ENV:Body>"
+                       "<m:%1 xmlns:m=\"%2\">")
+                       .arg(action)
+                       .arg(service);
 
-    for (const Arg & a : args)
+    for (const Arg &a : args)
         comm += "<" + a.element + ">" + a.value + "</" + a.element + ">";
 
     comm += QString("</m:%1></SOAP-ENV:Body></SOAP-ENV:Envelope>").arg(action);
