@@ -23,7 +23,6 @@
 
 namespace utp
 {
-
 TimeValue::TimeValue()
 {
     struct timeval tv;
@@ -32,23 +31,23 @@ TimeValue::TimeValue()
     microseconds = tv.tv_usec;
 }
 
-TimeValue::TimeValue(bt::Uint64 secs, bt::Uint64 usecs) : seconds(secs), microseconds(usecs)
+TimeValue::TimeValue(bt::Uint64 secs, bt::Uint64 usecs)
+    : seconds(secs)
+    , microseconds(usecs)
 {
 }
 
-TimeValue::TimeValue(const utp::TimeValue& tv) : seconds(tv.seconds), microseconds(tv.microseconds)
+TimeValue::TimeValue(const utp::TimeValue &tv)
+    : seconds(tv.seconds)
+    , microseconds(tv.microseconds)
 {
 }
 
-
-TimeValue& TimeValue::operator=(const utp::TimeValue& tv)
+TimeValue &TimeValue::operator=(const utp::TimeValue &tv)
 {
     seconds = tv.seconds;
     microseconds = tv.microseconds;
     return *this;
 }
 
-
-
 }
-
